@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2018 Red Hat, Inc.  All rights reserved.
+ * Copyright (C) 2010-2019 Red Hat, Inc.  All rights reserved.
  *
  * Authors: Fabio M. Di Nitto <fabbione@kronosnet.org>
  *          Federico Simoncelli <fsimon@kronosnet.org>
@@ -255,6 +255,12 @@ extern pthread_rwlock_t shlib_rwlock;       /* global shared lib load lock */
  *       for every protocol.
  */
 
+/*
+ * make it easier to map values in transports.c
+ */
+#define TRANSPORT_PROTO_NOT_CONNECTION_ORIENTED 0
+#define TRANSPORT_PROTO_IS_CONNECTION_ORIENTED  1
+
 typedef struct knet_transport_ops {
 /*
  * transport generic information
@@ -263,6 +269,13 @@ typedef struct knet_transport_ops {
 	const uint8_t transport_id;
 	const uint8_t built_in;
 
+/*
+ * connection oriented protocols like SCTP
+ * don´t need dst_addr in sendto calls and
+ * on some OSes are considered EINVAL.
+ */
+	uint8_t transport_is_connection_oriented;
+
 	uint32_t transport_mtu_overhead;
 /*
  * transport init must allocate the new transport
