@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2018 Red Hat, Inc.  All rights reserved.
+ * Copyright (C) 2017-2019 Red Hat, Inc.  All rights reserved.
  *
  * Authors: Fabio M. Di Nitto <fabbione@kronosnet.org>
  *
@@ -81,14 +81,14 @@ static void test(void)
 
 	flush_logs(logfds[0], stdout);
 
-	printf("Test knet_handle_compress with zlib compress and negative level\n");
+	printf("Test knet_handle_compress with zlib compress and negative level (-2)\n");
 
 	memset(&knet_handle_compress_cfg, 0, sizeof(struct knet_handle_compress_cfg));
 	strncpy(knet_handle_compress_cfg.compress_model, "zlib", sizeof(knet_handle_compress_cfg.compress_model) - 1);
-	knet_handle_compress_cfg.compress_level = -1;
+	knet_handle_compress_cfg.compress_level = -2;
 
 	if ((!knet_handle_compress(knet_h, &knet_handle_compress_cfg)) || (errno != EINVAL)) {
-		printf("knet_handle_compress accepted invalid (-1) compress level for zlib\n");
+		printf("knet_handle_compress accepted invalid (-2) compress level for zlib\n");
 		knet_handle_free(knet_h);
 		flush_logs(logfds[0], stdout);
 		close_logpipes(logfds);
